==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pt_PT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Sala",
    "Unknown" : "Desconhecido",
    "Required" : "Obrigatório",
    "Optional" : "Opcional",
    "Does not attend" : "Não comparecerá",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horária desconhecida ({tz}), a repor para UTC",
    "Please create a calendar first." : "Por favor, crie primeiro um calendário.",
    "New event" : "Novo evento",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetição",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Please add a title!" : "Por favor, adicione um titulo!",
    "Please select a calendar!" : "Por favor, selecione um calendário!",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Diariamente",
    "Every week" : "Semanalmente",
    "Every month" : "Mensalmente",
    "Every year" : "Anualmente",
    "never" : "nunca",
    "after" : "depois",
    "At time of event" : "À hora do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizado",
    "Audio" : "Áudio",
    "E Mail" : "Correio Eletrónico",
    "Pop up" : "Janela de Aviso",
    "sec" : "seg.",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "inicio",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Não é suportada a edição de lembretes do tipo desconhecido.",
    "Week {number} of {year}" : "Semana {number} do {year}",
    "Successfully imported" : "Importado com sucesso",
    "Partially imported, 1 failure" : "Parcialmente importado, 1 erro",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} erros",
    "Audio alarm" : "Alarme áudio",
    "Pop-up" : "Janela de Aviso",
    "E-Mail" : "Correio Eletrónico",
    "{type} {time} before the event starts" : "{type} {time} antes do evento começar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} depois do evento começar",
    "{type} {time} after the event ends" : "{type} {time} depois do evento terminar",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} às {time}",
    "{calendar} shared by {owner}" : "{calendar} partilhado por {owner}",
    "Title of the Event" : "Título do Evento",
    "starts" : "começa",
    "ends" : "termina",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização:",
    "Description" : "Descrição",
    "Export" : "Exportar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, contacte o seu administrador e peça-lhe para desativar a opção de configuração \"asset-pipeline.enabled\".",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Share Calendar" : "Comartilhar Calendário",
    "More" : "Mais",
    "Edit" : "Editar",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "can edit" : "pode editar",
    "group" : "grupo",
    "New Calendar" : "Novo Calendário",
    "Subscriptions" : "Subscrições",
    "New Subscription" : "Nova Subscrição",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar Evento",
    "Save Event" : "Guardar Evento",
    "Time" : "Tempo",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Add" : "Adicionar",
    "E-Mail address of attendee" : "Endereço de e-mail do participante",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione o seu endereço de e-mail nas configurações pessoais para poder adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "A regra de repetição deste evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "O suporte para as regras avançadas será adicionado nas atualizações subsequentes.",
    "Reset repeating rule" : "Reiniciar a regra de repetição",
    "Repeat every ..." : "Repetir a cada... ",
    "end repeat ..." : "terminar repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "A analisar o calendário",
    "The file contains objects incompatible with the selected calendar" : "O ficheiro contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "Import scheduled" : "Importação agendada",
    "Settings" : "Configurações",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Sem Calendários selecionados para importar",
    "Primary CalDAV address" : "Endereço principal CalDAV",
    "iOS/OS X CalDAV address" : "Endereço CalDAV de iOS/OS X"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/pt_PT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendário",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Sala",
    "Unknown" : "Desconhecido",
    "Required" : "Obrigatório",
    "Optional" : "Opcional",
    "Does not attend" : "Não comparecerá",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horária desconhecida ({tz}), a repor para UTC",
    "Please create a calendar first." : "Por favor, crie primeiro um calendário.",
    "New event" : "Novo evento",
    "Attendees" : "Participantes",
    "Reminders" : "Lembretes",
    "Repeating" : "Repetição",
    "When shared show full event" : "Quando partilhado, mostrar evento completo",
    "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
    "When shared hide this event" : "Quando partilhado, ocultar este evento",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "Por favor, adicione um titulo!",
    "Please select a calendar!" : "Por favor, selecione um calendário!",
    "Global" : "Global",
    "None" : "Nenhum",
    "Every day" : "Diariamente",
    "Every week" : "Semanalmente",
    "Every month" : "Mensalmente",
    "Every year" : "Anualmente",
    "never" : "nunca",
    "after" : "depois",
    "At time of event" : "À hora do evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personalizado",
    "Audio" : "Áudio",
    "E Mail" : "Correio Eletrónico",
    "Pop up" : "Janela de Aviso",
    "sec" : "seg.",
    "min" : "min",
    "hours" : "horas",
    "days" : "dias",
    "week" : "semana",
    "before" : "antes",
    "start" : "inicio",
    "end" : "fim",
    "Editing reminders of unknown type not supported." : "Não é suportada a edição de lembretes do tipo desconhecido.",
    "Week {number} of {year}" : "Semana {number} do {year}",
    "Successfully imported" : "Importado com sucesso",
    "Partially imported, 1 failure" : "Parcialmente importado, 1 erro",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} erros",
    "Audio alarm" : "Alarme áudio",
    "Pop-up" : "Janela de Aviso",
    "E-Mail" : "Correio Eletrónico",
    "{type} {time} before the event starts" : "{type} {time} antes do evento começar",
    "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
    "{type} {time} after the event starts" : "{type} {time} depois do evento começar",
    "{type} {time} after the event ends" : "{type} {time} depois do evento terminar",
    "{type} at the event's start" : "{type} no início do evento",
    "{type} at the event's end" : "{type} no final do evento",
    "{type} at {time}" : "{type} às {time}",
    "{calendar} shared by {owner}" : "{calendar} partilhado por {owner}",
    "Title of the Event" : "Título do Evento",
    "starts" : "começa",
    "ends" : "termina",
    "All day Event" : "Evento todo o dia",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Mais...",
    "Create" : "Criar",
    "Update" : "Atualizar",
    "Close" : "Fechar",
    "Location" : "Localização:",
    "Description" : "Descrição",
    "Export" : "Exportar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, contacte o seu administrador e peça-lhe para desativar a opção de configuração \"asset-pipeline.enabled\".",
    "Day" : "Dia",
    "Week" : "Semana",
    "Month" : "Mês",
    "Today" : "Hoje",
    "Share Calendar" : "Comartilhar Calendário",
    "Shared" : "Partilhado",
    "More" : "Mais",
    "Edit" : "Editar",
    "Link" : "Hiperligação",
    "Download" : "Transferir",
    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
    "can edit" : "pode editar",
    "group" : "grupo",
    "New Calendar" : "Novo Calendário",
    "Subscriptions" : "Subscrições",
    "New Subscription" : "Nova Subscrição",
    "Url" : "Url",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar Evento",
    "Save Event" : "Guardar Evento",
    "Time" : "Tempo",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "vezes a cada",
    "Add" : "Adicionar",
    "E-Mail address of attendee" : "Endereço de e-mail do participante",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione o seu endereço de e-mail nas configurações pessoais para poder adicionar participantes.",
    "from" : "de",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "A regra de repetição deste evento ainda não é suportada.",
    "Support for advanced rules will be added with subsequent updates." : "O suporte para as regras avançadas será adicionado nas atualizações subsequentes.",
    "Reset repeating rule" : "Reiniciar a regra de repetição",
    "Repeat every ..." : "Repetir a cada... ",
    "end repeat ..." : "terminar repetição...",
    "times" : "vezes",
    "Import Calendars" : "Importar Calendários",
    "Import canceled" : "Importação cancelada",
    "Analyzing calendar" : "A analisar o calendário",
    "The file contains objects incompatible with the selected calendar" : "O ficheiro contém objetos incompatíveis com o calendário selecionado",
    "New calendar" : "Novo calendário",
    "Import scheduled" : "Importação agendada",
    "Settings" : "Configurações",
    "Import calendar" : "Importar calendário",
    "No Calendars selected for import" : "Sem Calendários selecionados para importar",
    "Primary CalDAV address" : "Endereço principal CalDAV",
    "iOS/OS X CalDAV address" : "Endereço CalDAV de iOS/OS X"
},
"nplurals=2; plural=(n != 1);");
